Elliptic curve group operations.
This crate provides elliptic curve point arithmetic built on top of
the finite field primitives in fp.
Modules
- curve_
edwards - Elliptic curve definition in Edwards form.
- curve_
hessian - Elliptic curve definition in (generalized) Hessian form.
- curve_
jacobi_ intersection - Elliptic curve definition in Jacobi intersection form.
- curve_
jacobi_ quartic - Elliptic curve definition in (extended) Jacobi quartic form.
- curve_
montgomery - Elliptic curve definition (Montgomery form).
- curve_
ops - Generic curve abstraction.
- curve_
weierstrass - Elliptic curve definition (general Weierstrass form).
- point_
edwards - Point representation and group law for Edwards curves.
- point_
hessian - Projective points on a generalized Hessian curve.
- point_
jacobi_ intersection - Affine points on a Jacobi-intersection curve.
- point_
jacobi_ quartic - Affine points on a Jacobi quartic curve.
- point_
montgomery - X-only arithmetic on a Montgomery curve via the Kummer line.
- point_
ops - Generic point abstraction.
- point_
weierstrass - Elliptic curve point representation and group law.