Crate ec

Crate ec 

Elliptic curve group operations.

This crate provides elliptic curve point arithmetic built on top of the finite field primitives in fp.

Modules

curve_edwards
Elliptic curve definition in Edwards form.
curve_hessian
Elliptic curve definition in (generalized) Hessian form.
curve_jacobi_intersection
Elliptic curve definition in Jacobi intersection form.
curve_jacobi_quartic
Elliptic curve definition in (extended) Jacobi quartic form.
curve_montgomery
Elliptic curve definition (Montgomery form).
curve_ops
Generic curve abstraction.
curve_weierstrass
Elliptic curve definition (general Weierstrass form).
point_edwards
Point representation and group law for Edwards curves.
point_hessian
Projective points on a generalized Hessian curve.
point_jacobi_intersection
Affine points on a Jacobi-intersection curve.
point_jacobi_quartic
Affine points on a Jacobi quartic curve.
point_montgomery
X-only arithmetic on a Montgomery curve via the Kummer line.
point_ops
Generic point abstraction.
point_weierstrass
Elliptic curve point representation and group law.