Affine points on a Jacobi quartic curve.
We use the affine model
$$ y^2 = d x^4 + 2 a x^2 + 1 $$
with neutral element $(0, 1)$ and negation $-(x, y) = (-x, y)$. The doubling formulas are taken from equations (9) and (10) in Jacobi Quartic Curves Revisited; the general addition uses affine formulas (1) and (2).
Important: these are affine formulas. Like the existing Edwards code in this crate, they assume denominators are invertible. For exceptional inputs where the result leaves this affine chart, the code panics instead of trying to model the desingularized points at infinity.
Structs
- Jacobi
Quartic Point - An affine point
(x, y)on a Jacobi quartic curve.