pub struct KummerPoint<F: FieldOps + Copy> {
pub x: F,
pub z: F,
}Expand description
A point on the Kummer line of a Montgomery curve, represented by (X : Z).
The affine x-coordinate is x = X / Z when Z ≠ 0.
A conventional choice is:
(1 : 0)for the identity image,(X : Z)withZ ≠ 0for finite x-coordinates.
Fields
x: FProjective x coordinate
z: FProjective z coordinate
Implementations
Sourceimpl<F: FieldOps> KummerPoint<F>
impl<F: FieldOps> KummerPoint<F>
Sourcepub fn from_x(x: F) -> Self
pub fn from_x(x: F) -> Self
Construct the finite x-line point corresponding to the affine
x-coordinate x, i.e. (x : 1).
Sourcepub fn is_identity(&self) -> bool
pub fn is_identity(&self) -> bool
Return true if this point is the image of identity.
Sourceimpl<F: FieldOps + Copy> KummerPoint<F>
impl<F: FieldOps + Copy> KummerPoint<F>
Sourcepub fn xdouble(&self, curve: &MontgomeryCurve<F>) -> Self
pub fn xdouble(&self, curve: &MontgomeryCurve<F>) -> Self
Point doubling on the Kummer line.
Given x(P) in projective form (X:Z), compute x([2]P).
Sourcepub fn xadd(&self, other: &Self, diff: &Self) -> Self
pub fn xadd(&self, other: &Self, diff: &Self) -> Self
Differential addition. Given (in projective form (X:Z)):
self = x(P),other = x(Q),diff = x(P - Q),
compute x(P + Q).
Sourcepub fn scalar_mul(&self, k: &[u64], curve: &MontgomeryCurve<F>) -> Self
pub fn scalar_mul(&self, k: &[u64], curve: &MontgomeryCurve<F>) -> Self
Montgomery ladder for scalar multiplication.
Given an x-line point x(P) and a scalar k, compute x([k]P).
The scalar k is given as a slice of u64 limbs in little-endian
order (same convention as FieldOps::pow).