pub struct AffinePoint<F: FieldOps> {
pub x: F,
pub y: F,
pub infinity: bool,
}Expand description
An affine point on a Weierstrass elliptic curve over F.
The point at infinity is represented by infinity = true; in that case
the x and y fields are meaningless (set to zero by convention).
Fields
x: Fx coordinate
y: Fy coordinate
infinity: booltrue if and only if the ponit at infinity
Implementations
Sourceimpl<F: FieldOps> AffinePoint<F>
impl<F: FieldOps> AffinePoint<F>
Sourcepub fn new(x: F, y: F) -> Self
pub fn new(x: F, y: F) -> Self
Construct a finite affine point (x, y).
No on-curve check is performed; use
WeierstrassCurve::contains if you need validation.
Sourcepub fn is_identity(&self) -> bool
pub fn is_identity(&self) -> bool
Returns true if this is the point at infinity.
Sourceimpl<F: FieldOps> AffinePoint<F>
impl<F: FieldOps> AffinePoint<F>
Sourcepub fn negate(&self, curve: &WeierstrassCurve<F>) -> Self
pub fn negate(&self, curve: &WeierstrassCurve<F>) -> Self
Negate a point: -(x, y) = (x, −y − a₁x − a₃).
Sourcepub fn double(&self, curve: &WeierstrassCurve<F>) -> Self
pub fn double(&self, curve: &WeierstrassCurve<F>) -> Self
Double a point: [2]P.
Uses the tangent-line formula for the general Weierstrass model:
λ = (3x₁² + 2a₂x₁ + a₄ − a₁y₁) / (2y₁ + a₁x₁ + a₃)
x₃ = λ² + a₁λ − a₂ − 2x₁
y₃ = λ(x₁ − x₃) − y₁ − a₁x₃ − a₃Returns O when the tangent is vertical (i.e. 2y + a₁x + a₃ = 0).
Sourcepub fn add(&self, other: &Self, curve: &WeierstrassCurve<F>) -> Self
pub fn add(&self, other: &Self, curve: &WeierstrassCurve<F>) -> Self
Add two points: P + Q.
Handles all cases:
- Either operand is
O→ return the other. P = Q→ delegate todouble.P = −Q(same x, opposite y) → returnO.- General chord:
λ = (y₂ − y₁) / (x₂ − x₁)
x₃ = λ² + a₁λ − a₂ − x₁ − x₂
y₃ = λ(x₁ − x₃) − y₁ − a₁x₃ − a₃Sourcepub fn scalar_mul(
&self,
k: &[u64],
curve: &<AffinePoint<F> as PointOps>::Curve,
) -> Self
pub fn scalar_mul( &self, k: &[u64], curve: &<AffinePoint<F> as PointOps>::Curve, ) -> Self